@@ -45,7 +45,8 @@ async def readiness_check():
 
     """
     log.info("Started GET /ready")
-    {% if cookiecutter.redis == "yes" %}
+    {%- if cookiecutter.redis == "yes" %}
+
     if settings.USE_REDIS and not await RedisClient.ping():
         log.error("Could not connect to Redis")
         raise HTTPException(
@@ -54,10 +55,13 @@ async def readiness_check():
                 code=502, message="Could not connect to Redis"
             ).dict(exclude_none=True),
         )
-    {% else %}
+
+    {%- else %}
+
     if settings.USE_REDIS:
         log.warning(
             "Redis utility skipped. Please set FASTAPI_USE_REDIS=false"
         )
-    {% endif %}
+
+    {%- endif %}
     return ReadyResponse(status="ok")
